@@ -37,7 +37,7 @@ def create_upload_data(content_type, key):
     region = getattr(settings, 'S3DIRECT_REGION', None)
     endpoint = REGIONS.get(region, 's3.amazonaws.com')
 
-    expires_in = datetime.now() + timedelta(hours=5)
+    expires_in = datetime.utcnow() + timedelta(seconds=60*5)
     expires = expires_in.strftime('%Y-%m-%dT%H:%M:%S.000Z')
 
     policy_object = json.dumps({
